PooledResource

Struct PooledResource 

pub struct PooledResource<Pool: SealedPool<Resource>, Resource> { /* private fields */ }
A handle to Resource in a pool, which returns the Resource back to the pool when dropped.