ResetBuffer

Struct ResetBuffer 

pub struct ResetBuffer { /* private fields */ }
An implementation of ResetResource<Vec<u8>>.

ResetBuffer resets a Vec<u8> by either clearing it without reducing its capacity, or by resetting it to a new zero-capacity Vec<u8> if its capacity exceeds a chosen maximum capacity.

Implementations

Source

impl ResetBuffer

pub const fn new(max_buffer_capacity: usize) -> Self

Get an implementation of ResetResource<Vec<u8>>.

The created ResetBuffer resets a Vec<u8> by either clearing it without reducing its capacity, or by resetting it to a new zero-capacity Vec<u8> if its capacity exceeds max_buffer_capacity.