pub struct SharedUnboundedBufferPool(/* private fields */);Expand description
A threadsafe pool with a growable number of Vec<u8> buffers.
Implementations
Sourcepub fn new(max_buffer_capacity: usize) -> Self
pub fn new(max_buffer_capacity: usize) -> Self
Create a new SharedUnboundedBufferPool, which initially has zero Vec<u8> buffers.
Whenever a buffer is returned to the pool, if its capacity is at most max_buffer_capacity,
then Vec::clear is run on it; otherwise, it is replaced with a new empty Vec<u8>.
Sourcepub fn get(&self) -> PooledBuffer<Self>
pub fn get(&self) -> PooledBuffer<Self>
Get a buffer from the pool, returning a new empty buffer if none were available in the pool.
Sourcepub fn pool_size(&self) -> usize
pub fn pool_size(&self) -> usize
Get the total number of buffers in this pool, whether available or in-use.
Sourcepub fn available_buffers(&self) -> usize
pub fn available_buffers(&self) -> usize
Get the number of buffers in the pool which are not currently being used.